@@ -3,13 +3,12 @@ Create a GUI to allow an easy control for any user :D
 """
 import os.path
 import tkinter as tk
-from glob import glob,iglob
+from glob import glob, iglob
 from pathlib import Path
 from tkinter import ttk, filedialog
 from tkinter.messagebox import showerror, showinfo
 from urllib.parse import urlparse
 
-import yaml
 from PIL import Image
 from PIL import ImageTk
 from ttkthemes import ThemedTk
@@ -18,41 +17,63 @@ import Obsidian_Snippeter as manager
 from Obsidian_Snippeter.src import environment as envi
 from Obsidian_Snippeter.src import github_action as gt
 
+
 def select_snippet(repo_path, repo_name, file_tree, tree, exclude_tree, clone_exclude):
-    not_snippet = [file_tree.item(i)['values'][0] for i in file_tree.selection() if len(file_tree.item(i)['values'])>0]
-    obsidian_to_css(repo_path, repo_name, not_snippet,tree, exclude_tree, clone_exclude)
+    not_snippet = [
+        file_tree.item(i)["values"][0]
+        for i in file_tree.selection()
+        if len(file_tree.item(i)["values"]) > 0
+    ]
+    obsidian_to_css(
+        repo_path, repo_name, not_snippet, tree, exclude_tree, clone_exclude
+    )
+
 
 def pop_up_exclude(frame, BASEDIR, url, tree, exclude_tree, clone_exclude):
-    folder_name, folder_path=download(url)
+    folder_name, folder_path = download(url)
     if folder_path != "0":
         pop_list = tk.Toplevel(frame)
-        pop_list.title('Exclude CSS')
+        pop_list.resizable(False, False)
+        pop_list.title("Choose your CSS")
+        pop_list.grid_columnconfigure(1, weight=2)
         pop_list.grid_columnconfigure(0, weight=1)
-        pop_list.grid_columnconfigure(1, weight=0)
-        file_tree=ttk.Treeview(pop_list)
+        file_tree = ttk.Treeview(pop_list)
         file_tree.column("#0")
         file_tree.heading(
-            '#0',
-            text='Select all snippets',
+            "#0",
+            text="Unselect all snippets",
             anchor=tk.CENTER,
-            command = lambda: switch(file_tree),
+            command=lambda: switch(file_tree, True),
         )
-        file_tree.insert('', 'end', "Snippets")
-        file_repo = [x for x in glob(os.path.join(BASEDIR,str(folder_name), '**'), recursive=True) if x.endswith('css')]
+        file_tree.insert("", "end", "Snippets")
+        file_repo = [
+            x
+            for x in glob(os.path.join(BASEDIR, str(folder_name), "**"), recursive=True)
+            if x.endswith("css")
+        ]
         for i, name in enumerate(file_repo):
-            tupled=(str(name),)
-            snippet_name=os.path.basename(name)
+            tupled = (str(name),)
+            snippet_name = os.path.basename(name)
             file_tree.insert("", i, text=snippet_name, values=tupled)
-        file_tree.grid(column=0, row=1, sticky='ew')
+        file_tree.grid(column=0, row=1, columnspan=2)
 
         if len(file_repo) > 0:
             file_tree.selection_set(file_tree.get_children())
-        exclude_button=ttk.Button(
+        exclude_button = ttk.Button(
             pop_list,
-            text='Clone snippets',
-            command=lambda: select_snippet(folder_path,folder_name, file_tree, tree, exclude_tree, clone_exclude)
+            text="Clone snippets",
+            command=lambda: select_snippet(
+                folder_path, folder_name, file_tree, tree, exclude_tree, clone_exclude
+            ),
         )
-        exclude_button.grid(row=2, column=0, sticky='ew')
+        add_to_exclude = ttk.Button(
+            pop_list,
+            text="Add to excluded",
+            command=lambda: exclude_selected(file_tree),
+        )
+        exclude_button.grid(row=2, column=0, ipadx=3)
+        add_to_exclude.grid(column=1, row=2)
+
 
 def git_pull(repo_path):
     """
@@ -81,7 +102,7 @@ def get_environment():
     :return: vault : Path / Basedir : Path
     """
     VAULT, BASEDIR = envi.get_environments()
-    if len(str(VAULT)) == 0 or len(str(BASEDIR)) == 0:
+    if len(str(VAULT)) == 0 or len(str(BASEDIR)) == 0 or not os.path.isdir(VAULT) or not os.path.isdir(BASEDIR):
         return "", ""
     return VAULT, BASEDIR
 
@@ -136,24 +157,33 @@ def save_env(vault, folder_snippet):
         snippets = os.path.join(vault, ".obsidian", "snippets")
         Path(snippets).mkdir(exist_ok=True)  # Create snippets folder if not exists
 
-def obsidian_to_css(repo_path, repo_name,not_excluded,tree, exclude_tree, clone_exclude):
-    css_file=[]
+
+def obsidian_to_css(
+    repo_path, repo_name, not_excluded, tree, exclude_tree, clone_exclude
+):
+    css_file = []
+
     for i in not_excluded:
-        css_file=gt.move_to_obsidian(i)
+        css_files = gt.move_to_obsidian(i)
+        css_file.append(css_files)
+    css_file = sum(css_file, [])
+    css_file = [os.path.basename(x) for x in css_file]
     if len(css_file) > 0:
-        css_file = "\n- ".join(css_file)
-        if len(css_file) == 0:
+        css_file = "- " + "\n- ".join(css_file) + "\n"
+        if len(css_file) == 1:
             css_file = "".join(css_file)
         showinfo(
             title="🎉🎉🎉🎉🎉",
             message=f"{css_file} successfully added to Obsidian !",
-            )
+        )
         reload(tree)
         reload(exclude_tree)
         if clone_exclude.instate(["selected"]):
             gt.exclude_folder(repo_path)
     else:
         showerror(title="❌❌❌❌❌❌", message=f"There is no CSS file in {repo_name}.")
+
+
 def download(url):
     """
     Clone a repository
@@ -161,19 +191,21 @@ def download(url):
     :param url: URL to repo
     :return: /
     """
-    if len(url) !=0:
+    if len(url) != 0:
         repo_path = git_clone(url)
         repo_name = urlparse(url).path[1:].split("/")[1]
 
         if repo_path == "Already exists":
             showerror(title="❌❌❌❌❌❌", message=f"{repo_name} already exists.")
-            return "0","0"
+            return "0", "0"
         elif repo_path == "0":
             showerror(title="❌❌❌❌❌❌", message=f"{repo_name} doesn't exists.")
             return "0", "0"
         return repo_path, repo_name
     else:
-        showerror(title="❌❌❌❌❌❌", message="Please, fill the URL before trying to download !")
+        showerror(
+            title="❌❌❌❌❌❌", message="Please, fill the URL before trying to download !"
+        )
         return "0", "0"
 
 
@@ -188,7 +220,8 @@ def reload(tree):
     BASEDIR, VAULT = get_environment()
     tree.delete(*tree.get_children())
     all_repo = [x for x in glob(os.path.join(str(BASEDIR), "**")) if os.path.isdir(x)]
-    traverse_dir(BASEDIR, tree)
+    if BASEDIR != "" or VAULT != "":
+        traverse_dir(BASEDIR, tree)
     if len(all_repo) > 0:
         selection_all(tree)
     tree.heading("#0", text="Unselect all Snippets")
@@ -213,14 +246,18 @@ def unselect_all(tree):
         tree.selection_remove(item)
 
 
-def switch(tree):
+def switch(tree, popup=False):
     """
     Switch between select/deselect
     :param tree: Treeview
+    :param popup: If used in download popup
     :return:
     """
-    if len(tree.get_children()) > 1:
-        if len(tree.selection()) < len(tree.get_children()) - 1:
+    tree_length = len(tree.get_children())
+    if popup:
+        tree_length = tree_length - 1
+    if tree_length > 0:
+        if len(tree.selection()) < tree_length:
             tree.heading("#0", text="Unselect all Snippets")
             selection_all(tree)
         else:
@@ -252,14 +289,7 @@ def update_selected(tree):
     """
     BASEDIR, VAULT = get_environment()
     data = tree.selection()
-    exclude_file = os.path.join(BASEDIR, "exclude.yml")
-    if os.path.isfile(exclude_file):
-        with open(exclude_file, "r", encoding="utf-8") as f:
-            exclude = yaml.safe_load(f)
-    else:
-        f = open(exclude_file, "w", encoding="utf-8")
-        f.close()
-        exclude = []
+    exclude = gt.read_exclude(BASEDIR)
     info = []
     no_css = []
     git_repo = []
@@ -267,14 +297,11 @@ def update_selected(tree):
         if len(tree.item(i)["values"]) > 0:
             repo_path = tree.item(i)["values"][0]
             repo_name = tree.item(i)["text"]
-            if repo_path.endswith('.css'): #isfile
+            if repo_path.endswith(".css"):  # isfile
                 parent = str(Path(repo_path).parent)
             else:
                 parent = str(repo_path)
-            if (
-                os.path.isdir(os.path.join(parent, ".git"))
-                and not repo_name in exclude
-            ):
+            if os.path.isdir(os.path.join(parent, ".git")) and not repo_name in exclude:
                 git_pull(parent)
                 css_file = gt.move_to_obsidian(repo_path)
                 if len(css_file) > 0:
@@ -318,16 +345,15 @@ def exclude_selected(exclude_tree):
         showinfo(title="🎉🎉🎉🎉🎉", message=f"Excluded from future update:{info}")
 
 
-def configuration_menu(config):
+def configuration_menu(config, browse_png, BASEDIR, VAULT):
     """
     Create the configuration frame
     :param config: Frame
+    :param browse_png: Image
+    :param BASEDIR: Basedirectory
+    :param VAULT: Vault directory
     :return: /
     """
-    browse_path = os.path.join(manager.__path__[0], "src", "gui_bin", "folder.png")
-    browse_icon = Image.open(browse_path).resize((18, 18), Image.ANTIALIAS)
-    browse_png = ImageTk.PhotoImage(browse_icon)
-
     config1 = ttk.Label(
         config,
         text="Vault Path",
@@ -337,12 +363,10 @@ def configuration_menu(config):
     )
     config1.grid(row=0, column=1, ipadx=5, sticky=tk.W)
     vault_ui = ttk.Entry(config, font=40)
-    BASEDIR, VAULT = get_environment()
     vault_ui.grid(row=0, column=2, ipadx=100)
     vault_ui.insert("end", str(VAULT))
     b1 = ttk.Button(
         config,
-        text="browse",
         command=lambda: browsefunc(vault_ui, config),
         image=browse_png,
         padding=3,
@@ -363,7 +387,6 @@ def configuration_menu(config):
 
     b2 = ttk.Button(
         config,
-        text="browse",
         command=lambda: browsefunc(manager_ui, config),
         image=browse_png,
         padding=3,
@@ -376,12 +399,13 @@ def configuration_menu(config):
     b3.grid(row=2, column=2)
 
 
-def clone_menu(clone, tree, exclude_tree):
+def clone_menu(clone, tree, exclude_tree, BASEDIR):
     """
     Create the clone menu
     :param clone: Frame
     :param tree: Clone treeview
     :param exclude_tree: exclude treeview
+    :param BASEDIR: Base directory
     :return:
     """
     clone_url = ttk.Label(
@@ -405,39 +429,49 @@ def clone_menu(clone, tree, exclude_tree):
     )
     clone_exclude_label.grid(row=1, column=1, sticky="w")
     clone_exclude.grid(row=1, column=1, sticky="ne", ipadx=120)
-    BASEDIR, VAULT = get_environment()
     clone_download = ttk.Button(
         clone,
         text="Download",
-        command=lambda: pop_up_exclude(clone, BASEDIR, clone_entry.get(), tree, exclude_tree, clone_exclude),
+        command=lambda: pop_up_exclude(
+            clone, BASEDIR, clone_entry.get(), tree, exclude_tree, clone_exclude
+        ),
     )
     clone_download.grid(row=2, column=1, ipadx=120)
 
+
 def check_folder_contents(folder):
     if os.path.isdir(folder):
         if not any(os.scandir(folder)):
             return False
-        elif not any(iglob(os.path.join(folder, '*.css'))):
+        elif not any(iglob(os.path.join(folder, "*.css"))):
             return False
     return True
 
-def traverse_dir(path, tree, parent=''):
+
+def traverse_dir(path, tree, parent=""):
     for file in os.listdir(path):
-        fullpath=os.path.join(path, file)
-        if not '.git' in fullpath:
+        fullpath = os.path.join(path, file)
+        if not ".git" in fullpath:
             if check_folder_contents(fullpath):
-                if fullpath.endswith('css') or os.path.isdir(fullpath):
-                    node_id=tree.insert(parent, 'end', text=os.path.basename(fullpath).replace('.css', ''), value=(str(fullpath),), open=False)
+                if fullpath.endswith("css") or os.path.isdir(fullpath):
+                    node_id = tree.insert(
+                        parent,
+                        "end",
+                        text=os.path.basename(fullpath).replace(".css", ""),
+                        value=(str(fullpath),),
+                        open=False,
+                    )
                     if os.path.isdir(fullpath):
                         traverse_dir(fullpath, tree, node_id)
 
-def update_menu(update):
+
+def update_menu(update, BASEDIR):
     """
     Create the update menu
     :param update: Frame
+    :param BASEDIR: Base directory
     :return: treeview
     """
-    BASEDIR, VAULT = get_environment()
     update.grid_columnconfigure(0, weight=1)
     update.grid_columnconfigure(1, weight=0)
 
@@ -450,7 +484,8 @@ def update_menu(update):
         command=lambda: switch(tree),
     )
     all_repo = [x for x in glob(os.path.join(str(BASEDIR), "**")) if os.path.isdir(x)]
-    traverse_dir(BASEDIR,tree)
+    if BASEDIR != "":
+        traverse_dir(BASEDIR, tree)
     tree.grid(column=0, row=2, sticky="ew")
     if len(all_repo) > 0:
         tree.selection_set(tree.get_children())
@@ -463,13 +498,13 @@ def update_menu(update):
     return tree
 
 
-def exclude_menu(delete):
+def exclude_menu(delete, BASEDIR):
     """
     Create exclude menu
     :param delete: frame
-    :return: exclude treeviewx
+    :param BASEDIR: Basedirectory
+    :return: exclude treeview
     """
-    BASEDIR, VAULT = get_environment()
     delete.grid_columnconfigure(0, weight=1)
     delete.grid_columnconfigure(1, weight=0)
     all_repo = [x for x in glob(os.path.join(str(BASEDIR), "**")) if os.path.isdir(x)]
@@ -482,8 +517,9 @@ def exclude_menu(delete):
         anchor=tk.CENTER,
         command=lambda: switch(exclude_tree),
     )
-    traverse_dir(BASEDIR, exclude_tree)
-    exclude_tree.grid(column=0, row=2, sticky="ew")
+    if BASEDIR != "":
+        traverse_dir(BASEDIR, exclude_tree)
+    exclude_tree.grid(column=0, row=1, columnspan=2, sticky="ew")
     if len(all_repo) > 0:
         exclude_tree.selection_set(exclude_tree.get_children())
     exclude_button = ttk.Button(
@@ -534,12 +570,15 @@ def main():
     menu.add(clone, text="Clone")
     menu.add(delete, text="Exclude")
     menu.add(config, text="Configuration")
-
-    configuration_menu(config)
-    tree = update_menu(update)
-    exclude_tree = exclude_menu(delete)
-    clone_menu(clone, tree, exclude_tree)
-
+    browse_path = os.path.join(manager.__path__[0], "src", "gui_bin", "folder.png")
+    browse_icon = Image.open(browse_path).resize((18, 18), Image.ANTIALIAS)
+    browse_png = ImageTk.PhotoImage(browse_icon)
+    BASEDIR, VAULT = get_environment()
+    configuration_menu(config, browse_png, BASEDIR, VAULT)
+    tree = update_menu(update, BASEDIR)
+    exclude_tree = exclude_menu(delete, BASEDIR)
+    clone_menu(clone, tree, exclude_tree, BASEDIR)
+    root.resizable(False, False)
     root.mainloop()
 
 
